**Example 1: 新建主机账号**

新建主机账号

Input: 

```
tccli dasb CreateDeviceAccount --cli-unfold-argument  \
    --Account xx \
    --DeviceId 1
```

Output: 
```
{
    "Response": {
        "Id": 1,
        "RequestId": "xx"
    }
}
```

